package com.install4j.api.context;

/**
 * The wizard context allows you to modify the GUI installer or uninstaller. It is returned by
 * {@link Context#getWizardContext()} and is only available if the installer or uninstaller
 * is running in GUI mode.
 * @author ej-technologies GmbH
 * @see Context#getWizardContext()
 */
public interface WizardContext {

    /**
     * Change the enabled status of the "Next" button at the bottom of the current screen.
     * This setting applies only to the currently displayed screen.
     * @param enabled if the button should be enabled or not
     */
    public void setNextButtonEnabled(boolean enabled);

    /**
     * Change the enabled status of the "Back" button at the bottom of the current screen.
     * This setting applies only to the currently displayed screen.
     * @param enabled if the button should be enabled or not
     */
    public void setBackButtonEnabled(boolean enabled);

    /**
     * Change the enabled status of the "Cancel" button at the bottom of the current screen.
     * This setting applies only to the currently displayed screen.
     * @param enabled if the button should be enabled or not
     */
    public void setCancelButtonEnabled(boolean enabled);

    /**
     * Change the visibility of the "Next" button at the bottom of the current screen.
     * This setting applies only to the currently displayed screen.
     * @param enabled if the button should be enabled or not
     */
    public void setNextButtonVisible(boolean enabled);

    /**
     * Change the visibility of the "Back" button at the bottom of the current screen.
     * This setting applies only to the currently displayed screen.
     * @param enabled if the button should be enabled or not
     */
    public void setBackButtonVisible(boolean enabled);

    /**
     * Change the visibility of the "Cancel" button at the bottom of the current screen.
     * This setting applies only to the currently displayed screen.
     * @param enabled if the button should be enabled or not
     */
    public void setCancelButtonVisible(boolean enabled);

    /**
     * Move to the next screen. This has the same effect as if the user clicks on the Next button.
     */
    public void pressNextButton();

    /**
     * Move to the previous screen. This has the same effect as if the user clicks on the Back button.
     */
    public void pressPreviousButton();

    /**
     * Cancel the installer or uninstaller. This has the same effect as if the user clicks on the Cancel button.
     */
    public void pressCancelButton();

    /**
     * Transfer the focus the Next button. This could be called in the "Post-activation" script of a screen.
     */
    public void focusNextButton();

}
