package com.install4j.api.screens;

import com.install4j.api.beans.AbstractBean;
import com.install4j.api.context.ProgressInterface;
import com.install4j.api.context.UninstallerContext;
import com.install4j.api.events.InstallerEvent;
import com.install4j.api.events.InstallerEventListener;

/**
 * Abstract base class for uninstaller screens.
 * All methods that have a reasonable default answer are overridden in the class.
 * This class saves the uninstaller context that is set by the framework and provides a getter for it.
 *
 * @author ej-technologies GmbH
 */
public abstract class AbstractUninstallerScreen extends AbstractBean implements UninstallerScreen, InstallerEventListener {

    private UninstallerContext context;

    public void setUninstallerContext(UninstallerContext context) {
        this.context = context;
    }

    public boolean isNextVisible() {
        return true;
    }

    public boolean isPreviousVisible() {
        return true;
    }

    public boolean isCancelVisible() {
        return true;
    }

    public boolean isHiddenForNext() {
        return false;
    }

    public boolean isHiddenForPrevious() {
        return false;
    }

    public void activated() {
    }

    public void deactivated() {
    }

    public void installerEvent(InstallerEvent event) {
    }

    public boolean next() {
        return true;
    }

    public boolean previous() {
        return true;
    }

    public boolean cancel() {
        return true;
    }

    public void willActivate() {

    }

    public boolean isHidden() {
        return false;
    }

    public boolean handleUnattended() {
        return true;
    }

    public boolean handleConsole(Console console) {
        return true;
    }

    public ProgressInterface getProgressInterface(ProgressInterface defaultProgressInterface) {
        return defaultProgressInterface;
    }

    public boolean hasTitlePanel() {
        return true;
    }

    /**
     * Returns the <tt>UninstallerContext</tt> that the framework has associated with
     * this custom screen in <tt>setUninstallerContext</tt>.
     * @return the uninstaller context.
     */
    public UninstallerContext getUninstallerContext() {
        return context;
    }

}
