package com.install4j.api.update;

import com.install4j.api.context.UserCanceledException;
import com.install4j.runtime.installer.helper.apiimpl.UpdateCheckerImpl;

import java.io.IOException;

/**
 * Utility class to download an update descriptor programatically from a given URL. In an installer
 * application, is is recommended to use the "Check for update" action instead. This class is mainly
 * intended for checking for updates in your application.
 *  
 * <p>In order to use this class in your application, please include <tt>resource/i4jruntime.jar</tt> from your
 * install4j installation into your class path. You do not need to distribute this file
 * along with your application, install4j will do this automatically for you.
 * </p>
 *
 * @see UpdateDescriptor
 * @author ej-technologies GmbH
 */
public class UpdateChecker {

    /**
     * Download an <tt>updates.xml</tt> file programatically from a given URL and returns an
     * {@link UpdateDescriptor} instance.
     * @param urlSpec the URL from which the  <tt>updates.xml</tt> file can be downloaded.
     * @param displayMode the display mode that should be used if proxy information should be required
     * @return the update descriptor
     * @throws UserCanceledException if the user cancels the proxy dialog
     * @throws IOException if the download fails
     */
    public static UpdateDescriptor getUpdateDescriptor(String urlSpec, ApplicationDisplayMode displayMode) throws UserCanceledException, IOException {
        return UpdateCheckerImpl.getUpdateDescriptor(urlSpec, displayMode);
    }
}
