package com.install4j.api.update;

/**
 * Enumeration class that represents the different update schedules. These values are used in the
 * {@link UpdateScheduleRegistry} class.
 * @author ej-technologies GmbH
 */
public class UpdateSchedule {

    /**
     *  {@link UpdateScheduleRegistry#checkAndReset()} always returns true
     */
    public static final UpdateSchedule ON_EVERY_START = new UpdateSchedule("On every start", "start");

    /**
     *  {@link UpdateScheduleRegistry#checkAndReset()} always returns true after more than one day has passed since
     * the last update
     */
    public static final UpdateSchedule DAILY = new UpdateSchedule("Daily", "daily");

    /**
     *  {@link UpdateScheduleRegistry#checkAndReset()} always returns true after more than one week has passed since
     * the last update
     */
    public static final UpdateSchedule WEEKLY = new UpdateSchedule("Weekly", "weekly");

    /**
     *  {@link UpdateScheduleRegistry#checkAndReset()} always returns true after more than one month has passed since
     * the last update
     */
    public static final UpdateSchedule MONTHLY = new UpdateSchedule("Monthly", "monthly");

    /**
     *  {@link UpdateScheduleRegistry#checkAndReset()} always returns false
     */
    public static final UpdateSchedule NEVER = new UpdateSchedule("Never", "never");

    /**
     * All values of <tt>UpdateSchedule</tt> for use in a drop-down list
     */
    public static final UpdateSchedule[] ALL_VALUES = new UpdateSchedule[] {ON_EVERY_START, DAILY, WEEKLY, MONTHLY, NEVER};

    /**
     * Returns the <tt>UpdateSchedule</tt> for a string ID. String IDs for  <tt>UpdateSchedule</tt>s are returned by
     * {@link #getId()}}.
     * @param id the ID
     * @return the <tt>UpdateSchedule</tt> or null if the ID is invalid
     */
    public static UpdateSchedule getById(String id) {
        for (int i = 0; i < ALL_VALUES.length; i++) {
            UpdateSchedule updateSchedule = ALL_VALUES[i];
            if (updateSchedule.getId().equals(id)) {
                return updateSchedule;
            }
        }
        return null;
    }

    private String verbose;
    private String id;

    private UpdateSchedule(String verbose, String id) {
        this.verbose = verbose;
        this.id = id;
    }

    /**
     * Returns the string ID for the <tt>UpdateSchedule</tt>. This string value can be saved and restored later with the
     * {@link #getById(String)}} method.
     * @return the ID
     */
    public String getId() {
        return id;
    }

    public String toString() {
        return verbose;
    }

}
